import peasy.*;
import controlP5.*;
import java.util.*;
import java.lang.*;

PeasyCam cam;
ControlP5 cp5;

Table bacteriaTable;
ArrayList<Ecoli> ecoliArray;
int numRows;

Accordion accordion;
ScrollableList strainDropdown;
Toggle toggleLines;

int minX = -50;
int maxX = 50;
int minY = -50;
int maxY = 50;
int minZ = -100;
int maxZ = 100;

void setup() {
  //size(1200, 800, P3D);
  fullScreen(P3D);
  cam = new PeasyCam(this, 250); 
  cam.setMinimumDistance(1);
  cam.setMaximumDistance(1000);
  smooth(4);
  
  accordionGUI();
  accordion.open(0,1,2);
  accordion.setCollapseMode(Accordion.MULTI);
  
  cp5.setAutoDraw(false);
  
  ecoliArray = new ArrayList<Ecoli>();
  fillTable("ImportDataStrain.csv", bacteriaTable, ecoliArray); 
  initializeArray();
}

void fillTable (String tablePath, Table table, ArrayList<Ecoli> anEcoliArray) {
  table = loadTable (tablePath, "header");
  numRows = table.getRowCount();
  for (int i=0; i < numRows; i++) {
    String strain = table.getString(i, 0);
    String treatment = table.getString(i, 1);
    float concentration = table.getFloat(i, 2);
    float od = table.getFloat(i, 3);
    Ecoli newEcoli = new Ecoli (strain, treatment, concentration, od);
    anEcoliArray.add(newEcoli);
  }}
  
  
void draw() {
  
  background(0);
  disableCam();

  Treatments treatments = new Treatments();
  
  strokeWeight(1);
  
  for (int i =0; i < numRows; i++) {
    Ecoli ecoli = ecoliArray.get(i);
    String strain = ecoli.strain;
    String treatment = ecoli.treatment;
    float concentration = ecoli.concentration;
    float OD = ecoli.OD;
    int graphNum = ecoli.graphNum;
    int strainNum = ecoli.strainNum;
    int linearConc = ecoli.linearConc;
    boolean phage = ecoli.Phage;
    boolean antibiotic = ecoli.Antibiotic;
    
    // X Conc, Y OD, Z TRX
    
    float x = map (linearConc, 0, 10, minX, maxX);
    float y = map (OD, 0.04, 1.28, minY, maxY);
    float z = map (graphNum, 1, 24, minZ, maxZ);
    
    stroke(255);
    
    if (strainNum == DisplayNum) {
      strokeWeight(2);
      
      if (treatmentBoolValues[graphNum-1]) {
        
        if (highlightAntibiotics) {
          if (antibiotic) {
            //stroke(#6CB66B);
            //strokeWeight(3);
            //point(x, -y, z);
            Point thePoint = new Point(x, -y, z);
            thePoint.setColor(#6CB66B);
            thePoint.setTheStroke(3);
            treatments.addToCorrectArray (graphNum, thePoint);}
          else {
            //stroke(#324C60);
            //strokeWeight(2);
            //point(x, -y, z);
            Point thePoint = new Point(x, -y, z);
            thePoint.setColor(#324C60);
            thePoint.setTheStroke(2);
            treatments.addToCorrectArray (graphNum, thePoint);}
        }
        
        else if (highlightPhages) {
          if (phage) {
            //stroke(#6CB66B);
            //strokeWeight(3);
            //point(x, -y, z);
            Point thePoint = new Point(x, -y, z);
            thePoint.setColor(#6CB66B);
            thePoint.setTheStroke(3);
            treatments.addToCorrectArray (graphNum, thePoint);}
          else {
            stroke(#324C60);
            strokeWeight(2);
            //point(x, -y, z);
            Point thePoint = new Point(x, -y, z);
            thePoint.setColor(#324C60);
            thePoint.setTheStroke(2);
            treatments.addToCorrectArray (graphNum, thePoint);}
        }
        else if (differStrain) {
          color c = colors[graphNum - 1];
          //stroke(c);
          //point(x, -y, z);
          Point thePoint = new Point(x, -y, z);
          thePoint.setColor(c);
          treatments.addToCorrectArray (graphNum, thePoint);
        }
        
        else {
          //point(x, -y, z);
          treatments.addToCorrectArray (graphNum, new Point(x, -y, z));
        }
      }
    }
    
    if (DisplayNum == 97) {
      strokeWeight(2);
      point(x, -y, z);}   
  }
  
  treatments.drawPoints();
  
  if (showLines || showFill) {
    treatments.drawLine(showFill);
  }
  if (showAverage) {
    treatments.drawAverageLine();
  }
  
  stroke(50);
  line(minX,-minY,maxZ, maxX, -minY, maxZ);
  line(minX,-minY,minZ, minX, -minY, maxZ);
  
  stroke(255);
  strokeWeight(0.5);
  noFill ();
  
  TreatmentNames();
  ConcentrationValues();
  gui();
  
}
